@@ -59,7 +59,7 @@ async def sync_preseem_model(preseem_model, nm_model, company_uuid, system=None,
                     logging.info('Created element: %s', r)
             bss_aps.add((model_site.uuid, ap.attributes['topology1']))
 
-    if delete:
+    if aps and delete:  # only do this if we have APs for multi-system deployments
         for elem_id, elem in model_elems.items():
             if elem_id not in bss_aps: 
                 if verbose:
